==> haskell-monad-journal-0.7.1-10-armv7h.pkg.tar.xz: usr/share/haskell/haskell-monad-journal/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: monad-journal
version: 0.7.1
id: monad-journal-0.7.1-30445f5e9b39786552a52a188cdfef1a
key: monad_C0FiUZyGHCI0UY4jIyrc55
license: BSD3
maintainer: Dimitri Sabadie <dimitri.sabadie@gmail.com>
homepage: http://github.com/phaazon/monad-journal
synopsis: Pure logger typeclass and monad transformer
description:
    This package provides a typeclass for logging in
    pure code, or more generally, in any kind of
    context. You can do whatever you want with
    logs, especially get them, clear them or even
    sink them through '\''IO'\'' if you'\''re logging in
    @(MonadIO m) => m@.
category: Control
author: Dimitri Sabadie <dimitri.sabadie@gmail.com>
exposed: True
exposed-modules:
    Control.Monad.Journal Control.Monad.Journal.Class
    Control.Monad.Trans.Journal
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/monad-journal-0.7.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/monad-journal-0.7.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/monad-journal-0.7.1
hs-libraries: HSmonad-journal-0.7.1-C0FiUZyGHCI0UY4jIyrc55
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    either-4.4.1-21ae2d1687c4725fd9b94c0f754d4fd7
    monad-control-1.0.1.0-0cce93e14e6c79e66d2dc881e1ab9f6e
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    transformers-base-0.4.4-b65bc998c24abf50fea29d4891da9e32
haddock-interfaces: /usr/share/doc/haskell-monad-journal/html/monad-journal.haddock
haddock-html: /usr/share/doc/haskell-monad-journal/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monad-journal-0.7.1-12-armv7h.pkg.tar.xz: usr/share/haskell/haskell-monad-journal/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: monad-journal
version: 0.7.1
id: monad-journal-0.7.1-3a626be79c00f2598a70f93649878d8a
key: monad_CwKG4iy0kceL1gjTufIfQ3
license: BSD3
maintainer: Dimitri Sabadie <dimitri.sabadie@gmail.com>
homepage: http://github.com/phaazon/monad-journal
synopsis: Pure logger typeclass and monad transformer
description:
    This package provides a typeclass for logging in
    pure code, or more generally, in any kind of
    context. You can do whatever you want with
    logs, especially get them, clear them or even
    sink them through '\''IO'\'' if you'\''re logging in
    @(MonadIO m) => m@.
category: Control
author: Dimitri Sabadie <dimitri.sabadie@gmail.com>
exposed: True
exposed-modules:
    Control.Monad.Journal Control.Monad.Journal.Class
    Control.Monad.Trans.Journal
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/monad-journal-0.7.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/monad-journal-0.7.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/monad-journal-0.7.1
hs-libraries: HSmonad-journal-0.7.1-CwKG4iy0kceL1gjTufIfQ3
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    either-4.4.1-034f73c037cf6acbd6a0e4686245d294
    monad-control-1.0.1.0-0cce93e14e6c79e66d2dc881e1ab9f6e
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    transformers-base-0.4.4-b65bc998c24abf50fea29d4891da9e32
haddock-interfaces: /usr/share/doc/haskell-monad-journal/html/monad-journal.haddock
haddock-html: /usr/share/doc/haskell-monad-journal/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
